# [pyhomely](https://pypi.org/project/pyhomely/)

![python version](https://img.shields.io/badge/Python-3.12<-->3.12-blue.svg)
[![PyPI](https://img.shields.io/pypi/v/pyhomely)](https://pypi.org/project/pyhomely)


## Installation

```bash
python3 -m install pyhomely
```

Look at the file `example.py` for a usage example.


## Contribute

**All** contributions are welcome!

1. Fork the repository
2. Clone the repository locally and open the devcontainer or use GitHub codespaces
3. Do your changes
4. Lint the files with `poetry run ruff check --fix pyhomely`
5. Format the files with `poetry run ruff format`
7. Commit your work, and push it to GitHub
8. Create a PR against the `main` branch
